@@ -20,6 +20,7 @@
 
 #include <config.h>
 
+#include <locale.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -50,7 +51,7 @@ static GOptionEntry options[] = {
         {"power-off", '\0', 0, G_OPTION_ARG_NONE, &opt_power_off, N_("Power off"), NULL},
         {"reboot", '\0', 0, G_OPTION_ARG_NONE, &opt_reboot, N_("Reboot"), NULL},
         {"force", '\0', 0, G_OPTION_ARG_NONE, &opt_force, N_("Ignoring any existing inhibitors"), NULL},
-        {"no-prompt", '\0', 0, G_OPTION_ARG_NONE, &opt_no_prompt, N_("Don't prompt for user confirmation"), NULL},
+        {"no-prompt", '\0', 0, G_OPTION_ARG_NONE, &opt_no_prompt, N_("Don’t prompt for user confirmation"), NULL},
         {NULL}
 };
 
@@ -157,9 +158,9 @@ do_power_off (const char *action)
                 g_warning ("Failed to call %s: %s",
                            action, error->message);
                 g_error_free (error);
+        } else {
+                g_variant_unref (reply);
         }
-
-        g_variant_unref (reply);
         g_clear_object (&sm_proxy);
 }
 
@@ -171,6 +172,7 @@ main (int argc, char *argv[])
         GOptionContext *ctx;
 
         /* Initialize the i18n stuff */
+        setlocale (LC_ALL, "");
         bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
